aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_control.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/pet_control/pet_control.h')
-rw-r--r--engines/titanic/pet_control/pet_control.h18
1 files changed, 14 insertions, 4 deletions
diff --git a/engines/titanic/pet_control/pet_control.h b/engines/titanic/pet_control/pet_control.h
index 6b40c15a6d..07a4ffa680 100644
--- a/engines/titanic/pet_control/pet_control.h
+++ b/engines/titanic/pet_control/pet_control.h
@@ -98,12 +98,12 @@ private:
*/
bool isBotInView(const CString &name) const;
- void setTimer44(int id, int val);
-
/**
* Find an object under a given root
*/
- CGameObject *findObject(const CString &name, CTreeItem *root);
+ CGameObject *findBot(const CString &name, CTreeItem *root);
+
+ void setTimer44(int id, int val);
protected:
bool MouseButtonDownMsg(CMouseButtonDownMsg *msg);
bool MouseDragStartMsg(CMouseDragStartMsg *msg);
@@ -302,6 +302,16 @@ public:
void onSummonBot(const CString &name, int val);
/**
+ * Dismiss an NPC
+ */
+ bool dismissBot(const CString &name);
+
+ /**
+ * Returns true if Doorbot or Bellbot present
+ */
+ bool isDoorOrBellbotPresent() const;
+
+ /**
* Start a timer for a Pet Area
*/
void startPetTimer(uint timerIndex, uint firstDuration, uint duration, CPetSection *target);
@@ -98,12 +98,12 @@ private:
/**
- * Find an object under a given root
+ * Find a bot under a given root
*/